package de.szut.casino.blackjack;

import de.szut.casino.blackjack.dto.CreateBlackJackGameDto;
import de.szut.casino.user.UserEntity;
import de.szut.casino.user.UserRepository;
import de.szut.casino.user.UserService;
import jakarta.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

@Slf4j
@RestController
public class BlackJackGameController {

    private final UserService userService;
    private final BlackJackGameRepository blackJackGameRepository;
    private final UserRepository userRepository;

    public BlackJackGameController(UserService userService, BlackJackGameRepository blackJackGameRepository, UserRepository userRepository) {
        this.userService = userService;
        this.blackJackGameRepository = blackJackGameRepository;
        this.userRepository = userRepository;
    }

    @PostMapping("/blackjack/start")
    public ResponseEntity<Object> createBlackJackGame(@RequestBody @Valid CreateBlackJackGameDto createBlackJackGameDto, @RequestHeader("Authorization") String token) {
        Optional<UserEntity> optionalUser = userService.getCurrentUser(token);

        if (optionalUser.isEmpty()) {
            return ResponseEntity.notFound().build();
        }

        UserEntity user = optionalUser.get();
        BigDecimal balance = user.getBalance();
        BigDecimal betAmount = createBlackJackGameDto.getBetAmount();

        if (betAmount.compareTo(BigDecimal.ZERO) <= 0) {
            Map<String, String> errorResponse = new HashMap<>();
            errorResponse.put("error", "Invalid bet amount");
            return ResponseEntity.badRequest().body(errorResponse);
        }

        if (betAmount.compareTo(balance) > 0) {
            Map<String, String> errorResponse = new HashMap<>();
            errorResponse.put("error", "Insufficient funds");
            return ResponseEntity.badRequest().body(errorResponse);
        }

        BlackJackGameEntity game = new BlackJackGameEntity();
        game.setUser(user);
        game.setBet(betAmount);

        user.setBalance(user.getBalance().subtract(betAmount));

        userRepository.save(user);
        blackJackGameRepository.save(game);

        return ResponseEntity.ok(game);
    }
}
